@@ -2,16 +2,24 @@ from pprint import pprint
 from sqlalchemy import BigInteger,\
                        Column
 
-from sqlalchemy_api_handler.bases.activator import Activator
+from sqlalchemy_api_handler.bases.tasker import Tasker
 from sqlalchemy_api_handler.utils.humanize import humanize
 
 
-class ApiHandler(Activator):
+class ApiHandler(Tasker):
 
     id = Column(BigInteger,
                 primary_key=True,
                 autoincrement=True)
 
+    @property
+    def dehumanizedId(self):
+        return self.id
+
+    @property
+    def humanizedId(self):
+        return humanize(self.id)
+
     def dump(self):
         pprint(vars(self))
 
